@@ -8,10 +8,10 @@
 # || License: GNU GPL version 2 or any later version.                       ||
 # ||                                                                        ||
 # +==========================================================================+
-# $Id: Change.pm 4160 2009-08-18 22:37:21Z christian-guest $
-# $Revision: 4160 $
+# $Id: Change.pm 4569 2010-01-07 22:29:06Z christian-guest $
+# $Revision: 4569 $
 # $HeadURL$
-# $Date: 2009-08-19 00:37:21 +0200 (Wed, 19 Aug 2009) $
+# $Date: 2010-01-07 23:29:06 +0100 (Thu, 07 Jan 2010) $
 # $Source$
 
 package CipUX::Object::Action::Attribute::Change;
@@ -33,7 +33,7 @@ use base qw(CipUX::Object::Action);
 
 {    # BEGIN CLASS
 
-    use version; our $VERSION = qv('3.4.0.2');
+    use version; our $VERSION = qv('3.4.0.3');
     use re 'taint';    # Keep data captured by parens tainted
     delete @ENV{qw(PATH IFS CDPATH ENV BASH_ENV)};    # Make %ENV safe
 
@@ -573,9 +573,16 @@ use base qw(CipUX::Object::Action);
 
         if ( ref $value_ar eq 'ARRAY' ) {
             foreach my $uid ( @{$value_ar} ) {
-                $logger->debug("value for that target is $uid");
-
-                push @return, "$dn_attr=$uid,$rdn,$basedn";
+                if ( ref $uid eq 'ARRAY' ) {
+                    foreach my $u ( @{$uid} ) {
+                        $logger->debug("value of target is $u");
+                        push @return, "$dn_attr=$u,$rdn,$basedn";
+                    }
+                }
+                else {
+                    $logger->debug("value for that target is $uid");
+                    push @return, "$dn_attr=$uid,$rdn,$basedn";
+                }
             }
         }
         else {
@@ -603,7 +610,7 @@ CipUX::Object::Action::Attribute::Change - Object layer class for CipUX
 
 =head1 VERSION
 
-version 3.4.0.2
+version 3.4.0.3
 
 =head1 SYNOPSIS
 
